﻿using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using Microsoft.SharePoint.Utilities;
using Microsoft.SharePoint.WebPartPages;

namespace RH.SitecollectionList
{
    /// <summary>
    /// Description of the toolpart. Override the GetToolParts method
    /// in your Web Part class to invoke this toolpart. To establish
    /// a reference to the Web Part the user has selected, use the
    /// ParentToolPane.SelectedWebPart property.
    /// </summary>
    public class CustomToolPart : ToolPart
    {
        // declaring variables
        private string AllWebapplications;
        private string UseSubwebs;

        // an event handler for the Init event
        private void CustomToolPart_Init(object sender, EventArgs e)
        {
            AllWebapplications = UniqueID + "AllWebapplications";
            UseSubwebs = UniqueID + "UseSubwebs";
        }

        /// <summary>
        /// Constructor for the class. A great place to set Set
        /// default values for additional base class properties
        /// here.
        /// <summary>
        public CustomToolPart()
        {
            // Set default properties
            Title = "René Hézser - Sitecollection List";
            Init += CustomToolPart_Init;
        }

        ///	<summary>
        ///	Called by the tool pane to apply property changes to
        /// the selected Web Part.
        ///	</summary>
        public override void ApplyChanges()
        {
            var wp1 = (RHSitecollectionList)ParentToolPane.SelectedWebPart;

            // Send the values to the Web Part.
            wp1.AllWebapplications = (SPEncode.HtmlEncode(Page.Request.Form[AllWebapplications]) == "on");
            wp1.UseSubwebs = (SPEncode.HtmlEncode(Page.Request.Form[UseSubwebs]) == "on");
        }

        /// <summary>
        ///	If the ApplyChanges method succeeds, this method is
        /// called by the tool pane to refresh the specified
        /// property values in the toolpart user interface.
        /// </summary>
        public override void SyncChanges()
        {
            // sync with the new property changes here
        }

        /// <summary>
        ///	Called by the tool pane if the user discards changes
        /// to the selected Web Part.
        /// </summary>
        public override void CancelChanges()
        {
        }

        /// <summary>
        /// Render this Tool part to the output parameter
        /// specified.
        /// </summary>
        /// <param name="writer">
        /// The HTML writer to write out to
        /// </param>
        protected override void RenderToolPart(HtmlTextWriter writer)
        {
            try
            {
                // Establish a reference to the Web Part.
                var wp1 = (RHSitecollectionList)ParentToolPane.SelectedWebPart;

                var cb1 = new CheckBox
                              {
                                  ID = (UniqueID + "AllWebapplications"),
                                  Checked = wp1.AllWebapplications,
                                  Text = "Show Sitecollections from all Webaplications"
                              };
                cb1.RenderControl(writer);
                writer.WriteLine("</br></br>");

                var cb2 = new CheckBox
                {
                    ID = (UniqueID + "UseSubwebs"),
                    Checked = wp1.UseSubwebs,
                    Text = "Show Subwebs instead of Sitecollections"
                };
                cb2.RenderControl(writer);
                writer.Write("</BR></BR>");
            }
            catch (Exception ex)
            {
                Controls.Add(new LiteralControl(ex.Message));
            }
        }
    }
}