using System;
using System.Web.UI;
using Microsoft.SharePoint.WebPartPages;
using System.Web.UI.WebControls;
using RH.Update;

namespace RH.SitecollectionList
{
    /// <summary>
    /// Description of the toolpart. Override the GetToolParts method
    /// in your Web Part class to invoke this toolpart. To establish
    /// a reference to the Web Part the user has selected, use the
    /// ParentToolPane.SelectedWebPart property.
    /// </summary>
    public class CustomToolPartFooter : ToolPart
    {
        private string _ErrorMessage = string.Empty;
        private Label _ServerVersion;

        // an event handler for the Init event
        private static void CustomToolPartFooter_Init(object sender, EventArgs e)
        {
        }

        /// <summary>
        /// Constructor for the class. A great place to set Set
        /// default values for additional base class properties
        /// here.
        /// <summary>
        public CustomToolPartFooter()
        {
            // Set default properties
            Title = "by Ren Hzser";
            Init += CustomToolPartFooter_Init;
        }

        ///	<summary>
        ///	Called by the tool pane to apply property changes to
        /// the selected Web Part.
        ///	</summary>
        public override void ApplyChanges()
        {
        }

        /// <summary>
        ///	If the ApplyChanges method succeeds, this method is
        /// called by the tool pane to refresh the specified
        /// property values in the toolpart user interface.
        /// </summary>
        public override void SyncChanges()
        {
        }

        /// <summary>
        ///	Called by the tool pane if the user discards changes
        /// to the selected Web Part.
        /// </summary>
        public override void CancelChanges()
        {
        }

        protected override void CreateChildControls()
        {
            base.CreateChildControls();

            try
            {
                var link = new HyperLink {NavigateUrl = "http://www.hezser.de/blog", Text = "www.hezser.de/blog", Target = "_blank"};
                Controls.Add(link);

                var wp1 = (RHSitecollectionList)ParentToolPane.SelectedWebPart;
                var currentVersion = new Label { Text = string.Format("<br/><br/>Current Version: {0}<br/>", wp1.Version) };
                Controls.Add(currentVersion);

                _ServerVersion = new Label {Text = "Latest Version:<br/>"};
                Controls.Add(_ServerVersion);

                var updateButton = new Button {ID = "UpdateButton", Text = "Check for updates"};
                updateButton.Click += updateButton_Click;
                Controls.Add(updateButton);
            }
            catch (Exception ex)
            {
                _ErrorMessage += string.Format("Error in CreateChildControls: {0}", ex);
            }
        }

        void updateButton_Click(object sender, EventArgs e)
        {
            try
            {
                var latest = new Updates("RH.SitecollectionList");
                LatestVersion latestVersion = latest.GetLatestVersion();
                if (latestVersion != null && latestVersion.Version != null)
                {
                    _ServerVersion.Text = string.Format("Latest Version: {0}<br/>", latestVersion.Version);
                }
            }
            catch (Exception ex)
            {
                _ErrorMessage += string.Format("<br/>Error: {0}", ex.Message);
            }        
        }

        /// <summary>
        /// Render this Tool part to the output parameter
        /// specified.
        /// </summary>
        /// <param name="writer">
        /// The HTML writer to write out to
        /// </param>
        protected override void RenderToolPart(HtmlTextWriter writer)
        {
            try
            {
                RenderChildren(writer);

                if (string.IsNullOrEmpty(_ErrorMessage) == false)
                {
                    writer.WriteLine(_ErrorMessage);
                }
            }
            catch (Exception ex)
            {
                writer.Write(string.Format("Error in CreateChildControls:\r\n{0}", Common.GetErrorMessage(ex)));
            }
        }
    }
}